{% extends "timepiece/base.html" %}

{% block title %}500 Internal Server Error{% endblock %}

{% block content %}
    <h1>Internal Server Error</h1>

    <p>A server error prevented this page from being displayed.  The system administrator has been notified and will investigate the problem as soon as possible.</p>
{% endblock %}
