<div class="bar-graph">
{% if error %}
    <div class="error">{{ error|safe }}</div>
{% else %}
    {% ifnotequal worked 0 %}
    <div title="{{ worked }}">
        <span>{{ worked }} hours worked</span>
    </div>
    {% endifnotequal %}
    {% ifnotequal left 0 %}
    <div title="{{ left }}">
        <span>({{ left }} hours remaining)</span>
    </div>
    {% endifnotequal %}
    {% ifnotequal over 0 %}
    <div title="{{ over }}">
        <span>({{ over }} hours over)</span>
    </div>
    {% endifnotequal %}
{% endif %}
</div>
