{% extends "timepiece/base.html" %}

{% block title %}404 Not Found{% endblock %}

{% block content %}
    <h1>Not Found</h1>

    <p>The requested URL {{ request.path }} was not found on this server.</p>
{% endblock %}
